//
//  ViewController.m
//  PTTest
//
//  Copyright (c) 2013 PunchTab, Inc. All rights reserved.
//

#import "MainViewController.h"
#import "LeaderboardTableViewController.h"
#import "RewardsTableViewController.h"

@interface MainViewController ()

- (void)setLoggedInState; 
- (void)setLoggedOutState; 

@end

@implementation MainViewController

@synthesize loginButton = _loginButton;
@synthesize logoutButton = _logoutButton;
@synthesize pointsButton = _pointsButton;
@synthesize leaderboardButton = _leaderboardButton;
@synthesize rewardsButton = _rewardsButton;
@synthesize ptController = _ptController;

#pragma mark Cleanup

- (void)unloadUI
{
    self.loginButton = nil;
    self.logoutButton = nil;
    self.pointsButton = nil;
    self.leaderboardButton = nil;
    self.rewardsButton = nil;    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (void)dealloc
{
    [self unloadUI];
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.title = @"PTTest";
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    [self unloadUI];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
    if (self.ptController.hasToken) {
        [self setLoggedInState];
    }
}

- (void)viewWillDisappear:(BOOL)animated
{
	[super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}

#pragma mark IBActions

- (void)loginButtonPressed:(id)sender 
{
    //Login with Punchtab external login
/*    [_ptController loginBlock:^(BOOL success, id response) {
        
    }];
 */
    //Login with SSO
    [_ptController loginWithUserId:@"user id" firstName:@"First name" lastName:@"last name" block:^(BOOL success, id response) {
        if (success) {
            [self setLoggedInState];
        }
    }];
}

- (IBAction)logoutButtonPressed:(id)sender
{
    [_ptController logoutBlock:^(BOOL success, id response) {
        if (success) {
            [self setLoggedOutState];
        }
    }];
}

- (IBAction)pointsButtonPressed:(id)sender 
{
    [_ptController sendActivity:@"visit" withPoints:100 block:^(BOOL success, id response) {
        if (success) {
            [_ptController getUserData];
        }
    }];
}

- (IBAction)leaderboardButtonPressed:(id)sender
{
    [_ptController getLeaderboardWithMe:YES block:^(BOOL success, id response) {
        LeaderboardTableViewController * tableVC = [[LeaderboardTableViewController alloc] initWithStyle:UITableViewStylePlain];
        tableVC.leaderboardData = response;
        [self.navigationController pushViewController:tableVC animated:YES];
    }];
}

- (IBAction)rewardsButtonPressed:(id)sender
{
    [_ptController getRewardsBlock:^(BOOL success, id response) {
        RewardsTableViewController * tableVC = [[RewardsTableViewController alloc] initWithStyle:UITableViewStylePlain];
        tableVC.rewardsData = response;
        tableVC.ptController = _ptController;
        [self.navigationController pushViewController:tableVC animated:YES];
    }];
}

#pragma mark Private methods

- (void)setLoggedInState 
{
    self.logoutButton.hidden = NO;
    self.loginButton.hidden = YES;
    self.pointsButton.hidden = NO;
    self.leaderboardButton.hidden = NO;
    self.rewardsButton.hidden = NO;    
}

- (void)setLoggedOutState 
{
    self.logoutButton.hidden = YES;
    self.loginButton.hidden = NO;
    self.pointsButton.hidden = YES;
    self.leaderboardButton.hidden = YES;
    self.rewardsButton.hidden = YES;    
}

@end
