//
//  RewardsTableViewController.m
//  PTTest
//
//  Copyright (c) 2013 PunchTab, Inc. All rights reserved.
//

#import "RewardsTableViewController.h"

@interface RewardsTableViewController ()

@property (nonatomic, strong) NSMutableArray * sections;

@end

@implementation RewardsTableViewController

@synthesize sections = _sections;
@synthesize rewardsData = _rewardsData;
@synthesize ptController = _ptController;

- (void)setRewardsData:(NSArray *)rewardsData 
{
    NSSortDescriptor * sort1 = [[NSSortDescriptor alloc] initWithKey:@"brand" ascending:YES]; 
    NSSortDescriptor * sort2 = [[NSSortDescriptor alloc] initWithKey:@"points" ascending:NO]; 
    NSArray * sortedData = [rewardsData sortedArrayUsingDescriptors:@[sort1, sort2]];
    
    NSMutableArray * currentSection = nil;
    NSString * currentBrand = nil;
    for (NSDictionary * dict in sortedData) 
    {
        NSString * brand = dict[@"brand"];
        if (![brand isEqualToString:currentBrand]) 
        {
            if (currentSection) 
            {
                [_sections addObject:currentSection];
            }
            currentSection = [NSMutableArray arrayWithCapacity:3];
            currentBrand = brand;
        }
        [currentSection addObject:dict];
    }
    if (currentSection) 
    {
        [_sections addObject:currentSection];
    }
}

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) 
    {
        self.sections = [NSMutableArray arrayWithCapacity:10];
    }
    return self;
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.title = @"Rewards";
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return _sections.count;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    NSArray * sectionList = _sections[section];
    return sectionList.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:CellIdentifier];
    }
    
    NSDictionary * cellData = _sections[indexPath.section][indexPath.row];
    cell.textLabel.text = cellData[@"name"];
    cell.textLabel.adjustsFontSizeToFitWidth = YES;
    cell.detailTextLabel.text = [NSString stringWithFormat:@"%@", cellData[@"points"]];

    return cell;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section
{
    NSArray * sectionList = _sections[0];
    NSDictionary * reward = sectionList[0];
    return reward[@"brand"];
}

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSNumber * rewardId = _sections[indexPath.section][indexPath.row][@"reward_id"];
    [_ptController redeemReward:rewardId block:^(BOOL success, id response) {
        [self.navigationController popViewControllerAnimated:YES];
    }];
}

@end